@@ -1,8 +1,24 @@
+import subprocess
 import numpy
-import xarray
 import matplotlib.pyplot as plt
-from osgeo import gdal
 from matplotlib import colors
+try:
+    import xarray
+except:
+    subprocess.run('pip install xarray',shell='true')
+    import xarray
+
+try:
+    from osgeo import gdal
+except:
+    subprocess.run('conda install -c conda-forge gdal',shell='true')
+    from osgeo import gdal
+
+try:
+    import sklearn
+except:
+    subprocess.run('pip install -U scikit-learn',shell='true')
+    import sklearn
 
 class objearth():
     def __init__(self):
